require 'thor'
require 'lorem-knight'
require 'rainbow'
require 'rainbow/ext/string'
require 'clipboard'

#trap("SIGINT") { exit! }

module LoremKnight
  def self.show_and_copy(lorem)
    puts "#{lorem}".color("#DCE35F")
    Clipboard.copy(lorem)
  end

  def self.configure_lorem(options, panther)
    panther.set_content_type(options[:html] ? 'html' : 'raw')
    panther.has_pre_sentence = options[:pre]
  end

  class CLI < Thor
    include Thor::Actions

    @@panther = LoremKnight::Panther.new
    map %w(-v --version) => :version
    map %w(-i --about) => :about

    desc 'version', 'lorem-knight version'
    def version
      puts LoremKnight::VERSION
    end

    desc 'about', 'about LoremKnight'
    def about
      puts LoremKnight::ABOUT
    end

    desc "s quantity", "generates LoremKnight sentences"
    option :pre,  :type => :boolean
    option :html, :type => :boolean
    def s(quantity)
      LoremKnight::configure_lorem(options, @@panther)
      LoremKnight::show_and_copy(@@panther.get_sentence(quantity.to_i))
    end

    desc "p quantity", "generates LoremKnight paragraphs"
    option :pre,  :type => :boolean
    option :html, :type => :boolean
    def p(quantity)
      LoremKnight::configure_lorem(options, @@panther)
      LoremKnight::show_and_copy(@@panther.get_paragraph(quantity.to_i))
    end

    desc "w quantity", "generates LoremKnight words"
    option :pre,  :type => :boolean
    option :html, :type => :boolean
    def w(quantity)
      LoremKnight::configure_lorem(options, @@panther)
      LoremKnight::show_and_copy(@@panther.get_words(quantity.to_i))
    end

    desc "l quantity", "generates LoremKnight html <ul> - s"
    option :pre,  :type => :boolean
    def l(quantity)
      LoremKnight::configure_lorem(options, @@panther)
      LoremKnight::show_and_copy(@@panther.get_list(quantity.to_i))
    end
  end
end
